%bcond_without libidn_enables_emacs

%ifarch %{java_arches}
%bcond_without libidn_enables_java
%endif

Summary: Internationalized Domain Name support library
Name: libidn
Version: 1.41
Release:    1%{?dist}
URL: http://www.gnu.org/software/libidn/
License: LGPLv2+ and GPLv3+ and GFDL
Source0: https://ftp.gnu.org/gnu/libidn/libidn-%{version}.tar.gz
Patch0: libidn-emacsopt.patch

BuildRequires: autoconf autoconf-archive
BuildRequires: automake
BuildRequires: libtool
BuildRequires: texinfo
BuildRequires: gcc
BuildRequires: gettext gettext-devel
BuildRequires: gtk-doc
%if %{with libidn_enables_emacs}
BuildRequires: emacs
%endif
BuildRequires: pkgconfig
BuildRequires: help2man
Provides: bundled(gnulib)
%if %{with libidn_enables_emacs}
Provides: emacs-libidn < 1.30-4
Requires: emacs-filesystem >= %{_emacs_version}
%endif
%if %{without libidn_enables_java}
%endif

%description
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package devel
Summary: Development files for the libidn library
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package includes header files and libraries necessary for
developing programs which use the GNU libidn library.

%if %{with libidn_enables_java}
%package java
Summary:       Java port of the GNU Libidn library
BuildRequires: java-devel
BuildRequires: javapackages-local
BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(junit:junit)
BuildRequires: make
BuildArch:     noarch

%description java
GNU Libidn is a fully documented implementation of the Stringprep,
Punycode and IDNA specifications. Libidn's purpose is to encode
and decode internationalized domain names.

This package contains the native Java port of the library.

%package javadoc
Summary:       Javadoc for %{name}-java
BuildArch:     noarch

%description javadoc
This package contains javadoc for %{name}-java.
%endif

%prep
%setup -q
%patch0 -p1 -b .emacsopt
autoreconf -vif
touch src/idn_cmd.c src/idn_cmd.h

find . -name '*.jar' -print -delete
find . -name '*.class' -print -delete

%if %{with libidn_enables_java}
%pom_remove_dep com.google.caliper:caliper java/pom.xml.in

%pom_remove_dep com.google.code.findbugs:annotations java/pom.xml.in
%endif

%build
%configure --disable-csharp --disable-static \
%if %{with libidn_enables_emacs}
    --enable-emacs \
    --with-lispdir=%{_emacs_sitelispdir}/%{name} \
%else
    --disable-emacs \
%endif
%if %{with libidn_enables_java}
    --enable-java
%else
    --disable-java
%endif

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

export LD_LIBRARY_PATH=$(pwd)/lib/.libs

%make_build

%check
export LD_LIBRARY_PATH=$(pwd)/lib/.libs
%make_build -C tests check VALGRIND=env

%install
%make_install pkgconfigdir=%{_libdir}/pkgconfig \
%if %{with libidn_enables_java}
    libidn_jardir=%{_javadir} \
%endif
    ;

%make_build -C examples distclean

find doc -name "Makefile*" | xargs rm
rm -rf %{buildroot}%{_datadir}/info/dir

sed -i '/gnu compiler/d' %{buildroot}%{_includedir}/idn-int.h

rm -f %{buildroot}%{_libdir}/*.la \
      %{buildroot}%{_datadir}/info/*.png

%if %{with libidn_enables_emacs}
%{_emacs_bytecompile} %{buildroot}%{_emacs_sitelispdir}/%{name}/*.el
%endif

%if %{with libidn_enables_java}
rm -rf doc/java/*
%javadoc -d doc/java $(find java/src/main/java -name "*.java")
rm -rf %{buildroot}%{_javadir}/libidn*.jar
%mvn_artifact java/pom.xml java/libidn-%{version}.jar
%mvn_file org.gnu.inet:libidn libidn
%mvn_install -J doc/java
%endif

%find_lang %{name}


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license COPYING*
%doc AUTHORS NEWS FAQ README THANKS
%{_bindir}/idn
%{_mandir}/man1/idn.1*
%{_libdir}/libidn.so.12*
%{_infodir}/%{name}.info*
%if %{with libidn_enables_emacs}
%{_emacs_sitelispdir}/%{name}
%endif

%files devel
%doc examples
%{_libdir}/libidn.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%if %{with libidn_enables_java}
%files java -f .mfiles
%license COPYING* java/LICENSE-2.0.txt

%files javadoc -f .mfiles-javadoc
%license COPYING* java/LICENSE-2.0.txt
%endif

%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.41-1
- initial build
